changeset 21:7ba615ef1593

change utf-8 string to rep-string-encoding variable.
author shinobu
date Sat, 10 Nov 2007 19:06:46 +0900
parents 5dc0243acd99
children e7ad3b65a553
files redit-client-sm.el
diffstat 1 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/redit-client-sm.el	Sat Nov 10 18:34:07 2007 +0900
+++ b/redit-client-sm.el	Sat Nov 10 19:06:46 2007 +0900
@@ -144,7 +144,7 @@
 ;; 	;;(set-process-coding-system redit-client-process
 ;; 	;;'raw-text 'raw-text)
 ;; 	(set-process-coding-system redit-client-process
-;; 				   'utf-8 'utf-8)
+;; 				   rep-string-encoding rep-string-encoding)
 ;; 	;; emacs が終了すると redit-client-process も終了する
 ;; 	(set-process-query-on-exit-flag redit-client-process nil)
 ;; 
@@ -177,11 +177,11 @@
   ;; called when the process receive packet
   (set-process-filter redit-client-process 'redit-client-process-filter)
 
-  ;; Code that is the process input/output buffer is utf-8
-  (set-process-coding-system redit-client-process 'utf-8 'utf-8)
+  ;; Code that is the process input/output buffer is rep-string-encoding
+  (set-process-coding-system redit-client-process rep-string-encoding rep-string-encoding)
 
   ;; ???
-  (set-process-query-on-exit-flag redit-client-process nil)
+  ;; (set-process-query-on-exit-flag redit-client-process nil)
     
   ;; not necessary since Emacs 21.1
   ;; (make-local-hook 'before-change-functions)
@@ -238,7 +238,7 @@
        (concat
 	(redit-pack
 	 (string-to-number redit-put-command) 0 0 0 0
-	 (string-bytes (encode-coding-string session-name 'utf-8)))
+	 (string-bytes (encode-coding-string session-name rep-string-encoding)))
 	session-name
 	)
        )